"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.specArrayToRegex = exports.isNull = exports.extractProjectionFunctionsObjects = exports.extractGroupByNames = exports.AdapterOperators = exports.isEmptyFilter = exports.updateFieldsFor = exports.isDate = exports.isObject = exports.asParamArrays = exports.patchVeloDateValue = exports.patchDateTimeValue = exports.patchDateTime = exports.EmptyFilter = exports.EmptySort = void 0;
const moment = require("moment");
const errors_1 = require("./errors");
exports.EmptySort = {
    sortExpr: '',
};
exports.EmptyFilter = {
    filterExpr: '',
    parameters: [],
    offset: 1
};
const patchDateTime = (item) => {
    const obj = {};
    for (const key of Object.keys(item)) {
        const value = item[key];
        obj[key] = (0, exports.patchDateTimeValue)(value);
    }
    return obj;
};
exports.patchDateTime = patchDateTime;
const patchDateTimeValue = (value) => {
    const reISO = /^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2}(?:\.\d*))(?:Z|(\+|-)([\d|:]*))?$/;
    if (value instanceof Date) {
        return moment(value).format('YYYY-MM-DD HH:mm:ss');
    }
    else if (reISO.test(value)) {
        return moment(new Date(value)).format('YYYY-MM-DD HH:mm:ss');
    }
    return value;
};
exports.patchDateTimeValue = patchDateTimeValue;
const patchVeloDateValue = (value) => {
    if ((0, exports.isObject)(value) && (0, exports.isDate)(value.$date)) {
        return new Date(value.$date);
    }
    return value;
};
exports.patchVeloDateValue = patchVeloDateValue;
const asParamArrays = (item) => Object.values(item);
exports.asParamArrays = asParamArrays;
const isObject = (o) => typeof o === 'object' && o !== null;
exports.isObject = isObject;
const isDate = (d) => {
    const reISO = /^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2}(?:\.\d*))(?:Z|(\+|-)([\d|:]*))?$/;
    const reISO2 = /^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2})(?:Z|(\+|-)([\d|:]*))?$/;
    return d instanceof Date || Object.prototype.toString.call(d) === '[object Date]' || (typeof d === 'string' && (reISO.test(d) || reISO2.test(d)));
};
exports.isDate = isDate;
const updateFieldsFor = (item) => {
    return Object.keys(item).filter(f => f !== '_id');
};
exports.updateFieldsFor = updateFieldsFor;
const isEmptyFilter = (filter) => {
    return (!filter || !filter.operator);
};
exports.isEmptyFilter = isEmptyFilter;
exports.AdapterOperators = {
    eq: 'eq',
    gt: 'gt',
    gte: 'gte',
    include: 'in',
    lt: 'lt',
    lte: 'lte',
    ne: 'ne',
    string_begins: 'begins',
    string_ends: 'ends',
    string_contains: 'contains',
    and: 'and',
    or: 'or',
    not: 'not',
    urlized: 'urlized',
    matches: 'matches'
};
const extractGroupByNames = (projection) => projection.filter((f) => !f.function).map((f) => f.name);
exports.extractGroupByNames = extractGroupByNames;
const extractProjectionFunctionsObjects = (projection) => projection.filter((f) => f.function);
exports.extractProjectionFunctionsObjects = extractProjectionFunctionsObjects;
const isNull = (value) => (value === null || value === undefined);
exports.isNull = isNull;
const specArrayToRegex = (spec) => {
    if (!Array.isArray(spec)) {
        throw new errors_1.InvalidQuery('$matches must have array - spec property');
    }
    return spec.map(specItemToRegex).join('');
};
exports.specArrayToRegex = specArrayToRegex;
const specItemToRegex = (spec) => {
    if (spec.type === 'literal') {
        return spec.value;
    }
    if (spec.type === 'anyOf') {
        return `[${spec.value}]`;
    }
    throw new errors_1.InvalidQuery('spec must have type of literal or anyOf');
};
//# sourceMappingURL=data_commons.js.map