"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CollectionChangeNotSupportedError = exports.UnrecognizedError = exports.UnsupportedDatabase = exports.UnsupportedSchemaOperation = exports.ItemNotFound = exports.DbConnectionError = exports.InvalidRequest = exports.InvalidQuery = exports.CannotModifySystemField = exports.FieldDoesNotExist = exports.ItemDoesNotExists = exports.ItemAlreadyExists = exports.FieldAlreadyExists = exports.CollectionAlreadyExists = exports.CollectionDoesNotExists = exports.UnauthorizedError = exports.BaseHttpError = void 0;
class BaseHttpError extends Error {
    constructor(message) {
        super(message);
    }
}
exports.BaseHttpError = BaseHttpError;
class UnauthorizedError extends BaseHttpError {
    constructor(message) {
        super(message);
    }
}
exports.UnauthorizedError = UnauthorizedError;
class CollectionDoesNotExists extends BaseHttpError {
    constructor(message, collectionName) {
        super(message);
        this.collectionName = collectionName !== null && collectionName !== void 0 ? collectionName : '';
    }
}
exports.CollectionDoesNotExists = CollectionDoesNotExists;
class CollectionAlreadyExists extends BaseHttpError {
    constructor(message, collectionName) {
        super(message);
        this.collectionName = collectionName !== null && collectionName !== void 0 ? collectionName : '';
    }
}
exports.CollectionAlreadyExists = CollectionAlreadyExists;
class FieldAlreadyExists extends BaseHttpError {
    constructor(message, collectionName, fieldName) {
        super(message);
        this.collectionName = collectionName !== null && collectionName !== void 0 ? collectionName : '';
        this.fieldName = fieldName !== null && fieldName !== void 0 ? fieldName : '';
    }
}
exports.FieldAlreadyExists = FieldAlreadyExists;
class ItemAlreadyExists extends BaseHttpError {
    constructor(message, collectionName, itemId) {
        super(message);
        this.itemId = itemId !== null && itemId !== void 0 ? itemId : '';
        this.collectionName = collectionName !== null && collectionName !== void 0 ? collectionName : '';
    }
}
exports.ItemAlreadyExists = ItemAlreadyExists;
class ItemDoesNotExists extends BaseHttpError {
    constructor(message, collectionName, itemId) {
        super(message);
        this.itemId = itemId !== null && itemId !== void 0 ? itemId : '';
        this.collectionName = collectionName !== null && collectionName !== void 0 ? collectionName : '';
    }
}
exports.ItemDoesNotExists = ItemDoesNotExists;
class FieldDoesNotExist extends BaseHttpError {
    constructor(message, collectionName, propertyName) {
        super(message);
        this.propertyName = propertyName !== null && propertyName !== void 0 ? propertyName : '';
        this.collectionName = collectionName !== null && collectionName !== void 0 ? collectionName : '';
    }
}
exports.FieldDoesNotExist = FieldDoesNotExist;
class CannotModifySystemField extends BaseHttpError {
    constructor(message) {
        super(message);
    }
}
exports.CannotModifySystemField = CannotModifySystemField;
class InvalidQuery extends BaseHttpError {
    constructor(message) {
        super(message);
    }
}
exports.InvalidQuery = InvalidQuery;
class InvalidRequest extends BaseHttpError {
    constructor(message) {
        super(message);
    }
}
exports.InvalidRequest = InvalidRequest;
class DbConnectionError extends BaseHttpError {
    constructor(message) {
        super(message);
    }
}
exports.DbConnectionError = DbConnectionError;
class ItemNotFound extends BaseHttpError {
    constructor(message) {
        super(message);
    }
}
exports.ItemNotFound = ItemNotFound;
class UnsupportedSchemaOperation extends BaseHttpError {
    constructor(message, collectionName, operation) {
        super(message);
        this.collectionName = collectionName !== null && collectionName !== void 0 ? collectionName : '';
        this.operation = operation !== null && operation !== void 0 ? operation : '';
    }
}
exports.UnsupportedSchemaOperation = UnsupportedSchemaOperation;
class UnsupportedDatabase extends BaseHttpError {
    constructor(message) {
        super(message);
    }
}
exports.UnsupportedDatabase = UnsupportedDatabase;
class UnrecognizedError extends BaseHttpError {
    constructor(message) {
        super(`Unrecognized Error: ${message}`);
    }
}
exports.UnrecognizedError = UnrecognizedError;
class CollectionChangeNotSupportedError extends BaseHttpError {
    constructor(message, collectionName, fieldName) {
        super(message);
        this.collectionName = collectionName !== null && collectionName !== void 0 ? collectionName : '';
        this.fieldName = fieldName !== null && fieldName !== void 0 ? fieldName : '';
    }
}
exports.CollectionChangeNotSupportedError = CollectionChangeNotSupportedError;
//# sourceMappingURL=errors.js.map