"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.appendQueryOperatorsTo = exports.allowedOperationsFor = exports.parseTableData = exports.validateSystemFields = exports.asWixSchemaHeaders = exports.asWixSchema = exports.ReadOnlyOperations = exports.ReadWriteOperations = exports.AllSchemaOperations = exports.EmptyCapabilities = exports.QueryOperatorsByFieldType = exports.FieldsWithPrecision = exports.PrimaryKeyField = exports.SystemFields = exports.PrimaryKeyFieldName = void 0;
const errors_1 = require("./errors");
const velo_external_db_types_1 = require("@wix-velo/velo-external-db-types");
exports.PrimaryKeyFieldName = '_id';
exports.SystemFields = [
    {
        name: exports.PrimaryKeyFieldName, type: 'text', subtype: 'string', precision: 255, isPrimary: true
    },
    {
        name: '_createdDate', type: 'datetime', subtype: 'datetime'
    },
    {
        name: '_updatedDate', type: 'datetime', subtype: 'datetime'
    },
    {
        name: '_owner', type: 'text', subtype: 'string', precision: 255
    }
];
exports.PrimaryKeyField = exports.SystemFields[0];
exports.FieldsWithPrecision = ['_id', '_owner'];
exports.QueryOperatorsByFieldType = {
    number: ['eq', 'ne', 'gt', 'gte', 'lt', 'lte', 'hasSome'],
    text: ['eq', 'ne', 'contains', 'startsWith', 'endsWith', 'hasSome', 'matches', 'gt', 'gte', 'lt', 'lte'],
    boolean: ['eq'],
    url: ['eq', 'ne', 'contains', 'hasSome'],
    datetime: ['eq', 'ne', 'gt', 'gte', 'lt', 'lte'],
    image: [],
    object: ['eq', 'ne', 'contains', 'startsWith', 'endsWith', 'hasSome', 'matches', 'gt', 'gte', 'lt', 'lte'],
};
exports.EmptyCapabilities = { sortable: false, columnQueryOperators: [] };
const QueryOperationsByFieldType = {
    number: [...exports.QueryOperatorsByFieldType.number, 'urlized'],
    text: [...exports.QueryOperatorsByFieldType.text, 'urlized', 'isEmpty', 'isNotEmpty'],
    boolean: exports.QueryOperatorsByFieldType.boolean,
    url: [...exports.QueryOperatorsByFieldType.url, 'urlized'],
    datetime: [...exports.QueryOperatorsByFieldType.datetime],
    image: exports.QueryOperatorsByFieldType.image,
    object: [...exports.QueryOperatorsByFieldType.object, 'isEmpty', 'isNotEmpty'],
};
exports.AllSchemaOperations = Object.values(velo_external_db_types_1.SchemaOperations);
exports.ReadWriteOperations = ['get', 'find', 'count', 'update', 'insert', 'remove', 'bulkRemove', 'bulkInsert', 'bulkUpdate'];
exports.ReadOnlyOperations = ['get'];
const asWixSchema = ({ id, allowedOperations, allowedSchemaOperations, fields }) => {
    return {
        id,
        displayName: id,
        allowedOperations,
        allowedSchemaOperations,
        maxPageSize: 50,
        ttl: 3600,
        fields: fields.reduce((o, r) => (Object.assign(Object.assign({}, o), { [r.field]: {
                displayName: r.field,
                type: r.type,
                queryOperators: r.queryOperators,
            } })), {})
    };
};
exports.asWixSchema = asWixSchema;
const asWixSchemaHeaders = (collectionName) => {
    return {
        id: collectionName,
        displayName: collectionName,
        maxPageSize: 50,
        ttl: 3600,
    };
};
exports.asWixSchemaHeaders = asWixSchemaHeaders;
const validateSystemFields = (columnName) => {
    if (exports.SystemFields.find(f => f.name === columnName)) {
        throw new errors_1.CannotModifySystemField('Cannot modify system field');
    }
    return Promise.resolve();
};
exports.validateSystemFields = validateSystemFields;
const parseTableData = (data) => data.reduce((o, r) => {
    const arr = o[r.table_name] || [];
    arr.push(r);
    o[r.table_name] = arr;
    return o;
}, {});
exports.parseTableData = parseTableData;
const allowedOperationsFor = ({ fields }) => fields.find((c) => c.field === '_id') ? exports.ReadWriteOperations : exports.ReadOnlyOperations;
exports.allowedOperationsFor = allowedOperationsFor;
const appendQueryOperatorsTo = (fields) => fields.map((f) => (Object.assign(Object.assign({}, f), { queryOperators: QueryOperationsByFieldType[f.type] })));
exports.appendQueryOperatorsTo = appendQueryOperatorsTo;
//# sourceMappingURL=schema_commons.js.map